##################################
### VoiceFservs.tcl            ###
### Version 1.3                ###
### By Wcc                     ###
### wcc@techmonkeys.org        ###
### http://www.dawgtcl.com:81/ ###
### EFnet #|DAWG|Tcl           ###
##################################

############################################################################
### Copyright  2000 - 2002 |DAWG| Scripting Group. All rights reserved. ###
############################################################################

################################################################################
## This script voices users who run an Fserv/FTP/TDCC/XDCC ad in the channel. ##
################################################################################

##############
## COMMANDS ##
################################################################
## DCC ## .chanset <channel> +/-voicefservs                   ##
######### Enables or disables Fserv auto-voice for a channel. ##
################################################################

##########################################################
## Just load the script, edit the settings, and rehash. ##
##########################################################

##########################################################################
# Enable anti-cheating? If enabled, this will wait untill the 2nd time   #
# an ad is seen to voice the server. If the next ad is within X seconds  #
# (defined below) of the first, the counter resets and the server cannot #
# obtain a voice for 5 minutes.                                          #
##########################################################################

set voicefservs_setting(anticheat) 1

############################################################################
# Set the required time between the 1st add and 2nd add here. This is only #
# required if anticheat is on.                                             #
############################################################################

set voicefservs_setting(anticheattime) "8"

###############################################################################
# Voice a user in multiple channels when an ad is seen? Set to "" to disable. #
###############################################################################

set voicefservs_setting(chans) "#betas #betas-xdcc"

###########################################################################
# Set the trigger words here. Put each set of trigger words on a separate #
# line. The trigger words do not have to be listed in the same order as   #
# they occur in the ad, but every trigger word in a set must exist in the #
# ad. Wildcards are supported.                                            #
###########################################################################

set voicefservs_setting(trigger) {
	"file server trigger queue"
	"fserv trigger queue"
	"ftp users l*p port"
	"tdcc send trigger queue"
	"send speed record queue"
	"send cps record queue"
	"slots open record packs"
	"snagged packs offering"
	"to request a file type msg xdcc send"
	"syntax xdcc send number"
	"file server online trigger"
	"file server online type"
}

####################
# Code begins here #
####################

if {![string match 1.6.* $version]} { putlog "\002VOICEFSERVS:\002 \002WARNING:\002 This script is intended to run on eggdrop 1.6.x or later." }
if {[info tclversion] < 8.2} { putlog "\002VOICEFSERVS:\002 \002WARNING:\002 This script is intended to run on Tcl Version 8.2 or later." }

setudef flag voicefservs
bind pubm - * voicefservs_parse

proc voicefservs_rcodes {text} {
	regsub -all -- {\002|\037|\026|\003([0-9][0-9]?(,[0-9][0-9]?)?)?} $text "" text
	return $text
}
proc voicefservs_parse {nick uhost hand chan text} {
	global voicefservs_cdata voicefservs_time voicefservs_disable
	if {![botisop $chan] || [isop $nick $chan] || [isvoice $nick $chan] || [lsearch -exact [channel info $chan] +voicefservs] == -1} { return }
	set text [voicefservs_rcodes [string tolower $text]]
	if {![info exists voicefservs_disable([set name [string tolower $nick!$chan]])]} { voicefservs_ed 0 $name }
	if {$voicefservs_disable($name)} { return }
	foreach trigger $::voicefservs_setting(trigger) {
		set ok 1
		foreach trigger2 $trigger {
			if {![string match "*$trigger2*" $text]} { set ok 0 ; break }
		}
		if {!$ok} { continue }
		if {!$::voicefservs_setting(anticheat)} { voicefservs_voice $nick $chan ; return }
		if {![info exists voicefservs_cdata($name)]} {
			set voicefservs_cdata($name) 0
			set voicefservs_time($name) [clock seconds]
			return
		}
		incr voicefservs_cdata($name)
		if {$voicefservs_cdata($name) < 0} {
			if {[expr ([clock seconds] - $voicefservs_time($name)) < $voicefservs_setting(anticheattime)]} { voicefservs_ed 1 $name ; return }
		}
		voicefservs_voice $nick $chan ; break
	}
}
proc voicefservs_ed {type name} {
	global voicefservs_disable
	switch -- $type {
		0 { set voicefservs_disable($name) 0 }
		1 {
			set voicefservs_disable($name) 1
			timer 5 [list voicefservs_ed 0 $name]
		}
	}
}
proc voicefservs_voice {nick chan2} {
	set chanlist $::voicefservs_setting(chans)
	lappend chanlist $chan2
	foreach chan $chanlist {
		if {[validchan $chan] && [botisop $chan] && [onchan $nick $chan] && ![isvoice $nick $chan] && ![isop $nick $chan]} { pushmode $chan +v $nick }
	}
}
putlog "\002VOICEFSERVS:\002 VoiceFservs.tcl Version 1.3 by Wcc is loaded."